<?php
if (!defined("PHPUnit_MAIN_METHOD")) {
    define("PHPUnit_MAIN_METHOD", "Science_Astronomy_SunRiseSetTest::main");
}

require_once "Science/Astronomy.php";
	
class Science_Astronomy_SunRiseSetTest extends PHPUnit_Framework_TestCase {
    var $handle;
	
    function main()
    {
        require_once "PHPUnit/TextUI/TestRunner.php";

        PHPUnit_TextUI_TestRunner::run(
            new PHPUnit_Framework_TestSuite("Science_Astronomy_SunRiseSetTest")
        );
    }

    function setUp()
    {
        $this->handle = new Science_Astronomy();
    }

    function testSunRiseSet()
    {
        $tests = array(
            0 => array(
                "latitude"  => 51.3000,
                "longitude" =>  6.7667,
                "timestamp" => mktime( 8, 31, 40,  8,  2, 2011, 1),
                "timezone"  =>  2
            ),
            1 => array(
                "latitude"  => 68.43,
                "longitude" => 17.42,
                "timestamp" => mktime( 0,  0,  0,  1,  3, 2000, 0),
                "timezone"  =>  1
            ),
            2 => array(
                "latitude"  => 67.43,
                "longitude" =>  0.0,
                "timestamp" => mktime( 0,  0,  0, 12, 25, 1999, 0),
                "timezone"  =>  0
            )
        );
        
        $results = array(
            0 => array(
                "rise"    => array("time" => "05:59", "azi" =>  59.4204),
                "set"     => array("time" => "21:20", "azi" => 300.2835),
                "message" => ""
            ),
            1 => array(
                "rise"    => array("time" => "--:--", "azi" => null),
                "set"     => array("time" => "--:--", "azi" => null),
                "message" => "Sun down all day"
            ),
            2 => array(
                "rise"    => array("time" => "11:53", "azi" => 178.2311),
                "set"     => array("time" => "12:08", "azi" => 181.7898),
                "message" => ""
            )
        );
        
        for ($i = 0; $i < sizeof($tests); $i++) {
            $sun = $this->handle->calculateSunRiseSet($tests[$i]["timestamp"], SCIENCE_ASTRONOMY_RET_STRING, $tests[$i]["latitude"], $tests[$i]["longitude"], $tests[$i]["timezone"]);
        
            $this->assertEquals($results[$i], $sun);
        }
    }
}

if (PHPUnit_MAIN_METHOD == 'Science_Astronomy_Test::main') {
    Science_Astronomy_SunRiseSetTest::main();
}
?>
